[![build](https://git.uibk.ac.at/c8441225/biquaternion_py/badges/main/pipeline.svg)](https://git.uibk.ac.at/c8441225/biquaternion_py/-/jobs)
[![coverage](https://git.uibk.ac.at/c8441225/biquaternion_py/badges/main/coverage.svg?job=run_tests)](https://git.uibk.ac.at/c8441225/biquaternion_py/-/jobs)


# biquaternion_py

This package implements the biquaternion algebra in python in a sympy compatible way.
The user can therefore not only calculate numerically, but also symbolically.
